# 実験終了

実験は正常に終了しました。

- 実行時間: `%(time)s`
- ログファイル: `%(logfile)s`

ログファイルを操作:

[ログファイルを開く](opensesame://event.after_experiment_open_logfile){: .important-button}<br />
[ログファイルを含むフォルダーを開く](opensesame://event.after_experiment_open_logfile_folder){: .button}<br />
[ログファイルをファイルプールにコピーする](opensesame://event.after_experiment_copy_logfile){: .button}
